pub fn unseal()Expand description
Re-open the audit for a new model load. Called from
crate::run_metrics::reset_for_new_run, which is where a run begins —
the next model runs its own eager lookups and gets its own gate.
pub fn unseal()Re-open the audit for a new model load. Called from
crate::run_metrics::reset_for_new_run, which is where a run begins —
the next model runs its own eager lookups and gets its own gate.